@@ -215,7 +215,7 @@ namespace acommon {
 	  {
 	    err.prim_err(bad_value, key, data,
 			 "a number between 0 and 1");
-	    goto ERROR;
+	    goto RETURN_ERROR;
 	  }
       } else if (key == "lib-dir") {
 	to_add->lib_dir = data;
@@ -228,7 +228,7 @@ namespace acommon {
 	itemize(data, to_add->dict_exts);
       } else {
 	err.prim_err(unknown_key, key);
-	goto ERROR;
+	goto RETURN_ERROR;
       }
     }
   
@@ -239,7 +239,7 @@ namespace acommon {
     *prev = to_add;
     return err;
 
-  ERROR:
+  RETURN_ERROR:
     delete to_add;
     return err;
   }
@@ -481,15 +481,15 @@ namespace acommon {
 
     for_dirs = dirs;
     err = module_info_list.fill(*this, c);
-    if (err.has_err()) goto ERROR;
+    if (err.has_err()) goto RETURN_ERROR;
 
     fill_helper_lists(dirs);
     err = dict_info_list.fill(*this, c);
-    if (err.has_err()) goto ERROR;
+    if (err.has_err()) goto RETURN_ERROR;
 
     return err;
 
-  ERROR:
+  RETURN_ERROR:
     clear();
     return err;
   }
